@@ -1,5 +1,9 @@
 from billy import db
 from billy.commands import BaseCommand
+from billy.utils import metadata
+from billy.importers.legislators import deactivate_legislators
+
+import datetime
 
 class Retire(BaseCommand):
     name = 'retire'
